#!/usr/bin/env python

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
# 
# Author : Nicolas Rougier
# Date   : 03/08/2007
# Version: beta
""" Attribute class.


"""


#________________________________________________________________________Import
import gtk
import sys
from renderer import *

#_______________________________________________________________class Attribute
class Attribute (object):
    """ Attribute description
    
        An attribute description is used to describe an attribute of an object
        and is mostly useful for representing the attribute within a graphical
        user interface.
    """

    #_________________________________________________________________ __init__
    def __init__ (self, obj, name, label = None, description = None,
                  read_only=False, use_label=True, inline=False):

        """ Create a new attribute.
        
        Function signatures
        -------------------
    
        __init__ (self, object, name, ...)
    
        Keyword arguments
        -----------------
 
        label -- a string describing the attribute.
                 default is the name of the attribute.

        description -- some (hopefully) useful description of the attribute.
                       default is None.

        read_only -- whether attribute is read only.
                     default is False unless attribute is read_only.

        use_label -- whether to use label.
                     default is True.
                     
        inline -- whether to display objects inline
                  default is False
        
        """
        
        self._object = obj
        self._name = name
        self._type = type (getattr(self._object, name))
        self._edited_value = getattr(self._object, name)

        if label:
            self.label = label
        else:
            self.label = name
        self.description = description
        self.read_only = read_only
        self.use_label = use_label
        if not read_only:
            try:    setattr (self._object, name, getattr(self._object, name))
            except: self.read_only = True

        # Choose a renderer according to attribute type
        if self._type is bool:
            self.renderer = BoolRenderer(self)
        elif self._type is int:
            self.renderer = IntRenderer(self)
        elif self._type is long:
            self.renderer = LongRenderer(self)
        elif self._type is float:
            self.renderer = FloatRenderer(self)
        elif self._type is complex:
            self.renderer = ComplexRenderer(self)
        elif self._type is str:
            self.renderer = StringRenderer(self)
        elif isinstance (getattr(self._object, name), object):
            if hasattr(getattr(self._object, name), 'attributes'):
                self.renderer = ViewRenderer(self)
            else:
                self.renderer = ObjectRenderer(self)
        elif self._type is tuple:
            print 'tuple'
        elif self._type is list:
            print 'list'
        elif self._type is dict:
            print 'dict'

    #_________________________________________________________________set_value
    def set_value (self, value):
        """ Set attribute to a new value, non reversible """
        
        setattr (self._object, self._name, value)

    #_________________________________________________________________get_value
    def get_value (self):
        """ Get current attribute value """

        return getattr(self._object, self._name)

    #__________________________________________________________set_edited_value
    def set_edited_value (self, value):
        """ Set edited value to a new value """

        self._edited_value = value

    #__________________________________________________________get_edited_value
    def get_edited_value (self):
        """ Get current edited value """
        
        return self._edited_value

