#!/usr/bin/env python

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
# 
# Author : Nicolas Rougier
# Date   : 03/08/2007
# Version: beta
""" Attribute class.


"""


#________________________________________________________________________Import
import gtk
import sys

#_____________________________________________________________class IntRenderer
class IntRenderer (object):
    """ Integer attribute renderer. 
    """
    
    #_________________________________________________________________ __init__
    def __init__ (self, attribute):
        """ Initialize renderer according to attribute """
        
        object.__init__ (self)
        self.attribute = attribute
        self.label = gtk.Label (self.attribute.label)
        self.label_use_markup = True
        self.label.set_alignment (1,0.5)
        self.editable = None
        self.view = None
        
        if self.attribute._type is int:
            adj = gtk.Adjustment (
                        0, -float(sys.maxint), float(sys.maxint), 1, 10, 10)
            self.editable = gtk.SpinButton (adj)    
            self.editable.set_value (self.attribute.get_value())
            self.signal_id = self.editable.connect ('value_changed',
                                                     self.on_change)

    #_________________________________________________________________on_change
    def on_change (self, widget):
        """ Callback on value change """
        
        edited_value = self.editable.get_value ()
        self.attribute.set_edited_value (edited_value)
        self.label.set_markup ('<b>%s*</b>' % self.attribute.label)
        if self.view:
            self.view.notify()

    #_____________________________________________________________________apply
    def apply (self):
        """ Apply last change  """
        
        value = self.editable.get_value ()
        self.attribute.set_value (value)
        self.attribute.set_edited_value (value)
        self.label.set_markup (self.attribute.label)
        if self.view:
            self.view.notify()

    #______________________________________________________________________undo
    def undo (self):
        """ Undo last change """

        self.editable.handler_block (self.signal_id)
        value = self.attribute.get_value ()
        edited_value = self.editable.get_value()
        self.editable.set_value (value)
        self.label.set_markup (self.attribute.label)
        self.editable.handler_unblock (self.signal_id)

    #______________________________________________________________________redo
    def redo (self):
        """ Redo last change """

        self.editable.handler_block (self.signal_id)
        edited_value = self.attribute.get_edited_value()
        self.editable.set_value (edited_value)
        self.label.set_markup ('<b>%s*</b>' % self.attribute.label)
        self.editable.handler_unblock (self.signal_id)

    
